==> jc-1.4.0.tar.gz: soot/coffi/TypeArray.h <==
// class soot.coffi.TypeArray

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9aade86b66c215a0 soot_coffi_TypeArray

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_TypeArray_H_
#define _JC_soot_coffi_TypeArray_H_

// Forward structure declarations
struct _jc_java_io_PrintStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Type$object;
struct _jc_soot_coffi_TypeArray$object;

// Typedefs
typedef struct _jc_soot_coffi_TypeArray$sub_refs	_jc_soot_coffi_TypeArray$sub_refs;
typedef struct _jc_soot_coffi_TypeArray$sub_nonrefs	_jc_soot_coffi_TypeArray$sub_nonrefs;
typedef struct _jc_soot_coffi_TypeArray$refs	_jc_soot_coffi_TypeArray$refs;
typedef struct _jc_soot_coffi_TypeArray$nonrefs	_jc_soot_coffi_TypeArray$nonrefs;
typedef struct _jc_soot_coffi_TypeArray$object	_jc_soot_coffi_TypeArray$object;

typedef const struct _jc_soot_coffi_TypeArray$vmethods	_jc_soot_coffi_TypeArray$vmethods;
typedef const struct _jc_soot_coffi_TypeArray$vtable	_jc_soot_coffi_TypeArray$vtable;
typedef const struct _jc_soot_coffi_TypeArray$vtype	_jc_soot_coffi_TypeArray$vtype;

// Constructors
extern void _jc_soot_coffi_TypeArray$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_TypeArray$object *);

// Virtual methods
extern jboolean _jc_soot_coffi_TypeArray$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_coffi_TypeArray$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_soot_Type$object *_jc_soot_coffi_TypeArray$method$get$9b522c783fc5ea65(_jc_env *, struct _jc_soot_coffi_TypeArray$object *, jint);
extern struct _jc_soot_coffi_TypeArray$object *_jc_soot_coffi_TypeArray$method$merge$87c3b3687298f8b8(_jc_env *, struct _jc_soot_coffi_TypeArray$object *, struct _jc_soot_coffi_TypeArray$object *);
extern void _jc_soot_coffi_TypeArray$method$print$7a0132e4af27b1ac(_jc_env *, struct _jc_soot_coffi_TypeArray$object *, struct _jc_java_io_PrintStream$object *);
extern struct _jc_soot_coffi_TypeArray$object *_jc_soot_coffi_TypeArray$method$set$9c242dfdfc03f6a1(_jc_env *, struct _jc_soot_coffi_TypeArray$object *, jint, struct _jc_soot_Type$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_TypeArray$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_coffi_TypeArray$method_info$get$9b522c783fc5ea65;
extern _jc_method _jc_soot_coffi_TypeArray$method_info$merge$87c3b3687298f8b8;
extern _jc_method _jc_soot_coffi_TypeArray$method_info$print$7a0132e4af27b1ac;
extern _jc_method _jc_soot_coffi_TypeArray$method_info$set$9c242dfdfc03f6a1;

// Static methods
extern struct _jc_soot_coffi_TypeArray$object *_jc_soot_coffi_TypeArray$method$v$b999cd6c95d4bcce(_jc_env *, jint);

// Virtual methods structure
struct _jc_soot_coffi_TypeArray$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_coffi_TypeArray$object *, struct _jc_java_lang_Object$object *);
	struct _jc_soot_Type$object	*(*get$9b522c783fc5ea65)(_jc_env *, struct _jc_soot_coffi_TypeArray$object *, jint);
	struct _jc_soot_coffi_TypeArray$object	*(*merge$87c3b3687298f8b8)(_jc_env *, struct _jc_soot_coffi_TypeArray$object *, struct _jc_soot_coffi_TypeArray$object *);
	void	(*print$7a0132e4af27b1ac)(_jc_env *, struct _jc_soot_coffi_TypeArray$object *, struct _jc_java_io_PrintStream$object *);
	struct _jc_soot_coffi_TypeArray$object	*(*set$9c242dfdfc03f6a1)(_jc_env *, struct _jc_soot_coffi_TypeArray$object *, jint, struct _jc_soot_Type$object *);
};

// Vtable
struct _jc_soot_coffi_TypeArray$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_TypeArray$vmethods	soot_coffi_TypeArray;
};

// Vtype
struct _jc_soot_coffi_TypeArray$vtype {
	_jc_type			type;
	_jc_soot_coffi_TypeArray$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_TypeArray$sub_refs {
	_jc_object_array	*types;
};

// Reference instance fields (object)
struct _jc_soot_coffi_TypeArray$refs {
    _jc_soot_coffi_TypeArray$sub_refs	soot_coffi_TypeArray;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_TypeArray$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_TypeArray$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_TypeArray$sub_nonrefs	soot_coffi_TypeArray;
};

// Object instance structure
struct _jc_soot_coffi_TypeArray$object {
	_jc_soot_coffi_TypeArray$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_TypeArray$vtype	*vtype;
	_jc_soot_coffi_TypeArray$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_TypeArray$vtype _jc_soot_coffi_TypeArray$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_TypeArray, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_TypeArray$class_object;

#endif	/* _JC_soot_coffi_TypeArray_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/TypeArray.h <==
// class soot.coffi.TypeArray

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9aade86b66c215a0 soot_coffi_TypeArray

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_TypeArray_H_
#define _JC_soot_coffi_TypeArray_H_

// Forward structure declarations
struct _jc_java_io_PrintStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Type$object;
struct _jc_soot_coffi_TypeArray$object;

// Typedefs
typedef struct _jc_soot_coffi_TypeArray$sub_refs	_jc_soot_coffi_TypeArray$sub_refs;
typedef struct _jc_soot_coffi_TypeArray$sub_nonrefs	_jc_soot_coffi_TypeArray$sub_nonrefs;
typedef struct _jc_soot_coffi_TypeArray$refs	_jc_soot_coffi_TypeArray$refs;
typedef struct _jc_soot_coffi_TypeArray$nonrefs	_jc_soot_coffi_TypeArray$nonrefs;
typedef struct _jc_soot_coffi_TypeArray$object	_jc_soot_coffi_TypeArray$object;

typedef const struct _jc_soot_coffi_TypeArray$vmethods	_jc_soot_coffi_TypeArray$vmethods;
typedef const struct _jc_soot_coffi_TypeArray$vtable	_jc_soot_coffi_TypeArray$vtable;
typedef const struct _jc_soot_coffi_TypeArray$vtype	_jc_soot_coffi_TypeArray$vtype;

// Constructors
extern void _jc_soot_coffi_TypeArray$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_TypeArray$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_coffi_TypeArray$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_coffi_TypeArray$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_Type$object *_jc_soot_coffi_TypeArray$method$get$9b522c783fc5ea65(_jc_env *, struct _jc_soot_coffi_TypeArray$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_soot_coffi_TypeArray$object *_jc_soot_coffi_TypeArray$method$merge$87c3b3687298f8b8(_jc_env *, struct _jc_soot_coffi_TypeArray$object *, struct _jc_soot_coffi_TypeArray$object *) _JC_JCNI_ATTR;
extern void _jc_soot_coffi_TypeArray$method$print$7a0132e4af27b1ac(_jc_env *, struct _jc_soot_coffi_TypeArray$object *, struct _jc_java_io_PrintStream$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_coffi_TypeArray$object *_jc_soot_coffi_TypeArray$method$set$9c242dfdfc03f6a1(_jc_env *, struct _jc_soot_coffi_TypeArray$object *, jint, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_TypeArray$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_coffi_TypeArray$method_info$get$9b522c783fc5ea65;
extern _jc_method _jc_soot_coffi_TypeArray$method_info$merge$87c3b3687298f8b8;
extern _jc_method _jc_soot_coffi_TypeArray$method_info$print$7a0132e4af27b1ac;
extern _jc_method _jc_soot_coffi_TypeArray$method_info$set$9c242dfdfc03f6a1;

// Static methods
extern struct _jc_soot_coffi_TypeArray$object *_jc_soot_coffi_TypeArray$method$v$b999cd6c95d4bcce(_jc_env *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_TypeArray$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_coffi_TypeArray$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_soot_Type$object	*(*get$9b522c783fc5ea65)(_jc_env *, struct _jc_soot_coffi_TypeArray$object *, jint) _JC_JCNI_ATTR;
	struct _jc_soot_coffi_TypeArray$object	*(*merge$87c3b3687298f8b8)(_jc_env *, struct _jc_soot_coffi_TypeArray$object *, struct _jc_soot_coffi_TypeArray$object *) _JC_JCNI_ATTR;
	void	(*print$7a0132e4af27b1ac)(_jc_env *, struct _jc_soot_coffi_TypeArray$object *, struct _jc_java_io_PrintStream$object *) _JC_JCNI_ATTR;
	struct _jc_soot_coffi_TypeArray$object	*(*set$9c242dfdfc03f6a1)(_jc_env *, struct _jc_soot_coffi_TypeArray$object *, jint, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_TypeArray$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_TypeArray$vmethods	soot_coffi_TypeArray;
};

// Vtype
struct _jc_soot_coffi_TypeArray$vtype {
	_jc_type			type;
	_jc_soot_coffi_TypeArray$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_TypeArray$sub_refs {
	_jc_object_array	*types;
};

// Reference instance fields (object)
struct _jc_soot_coffi_TypeArray$refs {
    _jc_soot_coffi_TypeArray$sub_refs	soot_coffi_TypeArray;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_TypeArray$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_TypeArray$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_TypeArray$sub_nonrefs	soot_coffi_TypeArray;
};

// Object instance structure
struct _jc_soot_coffi_TypeArray$object {
	_jc_soot_coffi_TypeArray$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_TypeArray$vtype	*vtype;
	_jc_soot_coffi_TypeArray$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_TypeArray$vtype _jc_soot_coffi_TypeArray$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_TypeArray, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_TypeArray$class_object;

#endif	/* _JC_soot_coffi_TypeArray_H_ */
